/*
 * MP3/MPlayer plugin to VDR (C++)
 *
 * (C) 2001,2002 Stefan Huelswitt <huels@iname.com>
 *
 * This code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * Or, point your browser to http://www.gnu.org/copyleft/gpl.html
 */

#ifndef ___DATA_MP3_H
#define ___DATA_MP3_H

#include "common.h"
#include "decoder.h"
#include <vdr/thread.h>

// ----------------------------------------------------------------

extern cFileSources MP3Sources;

class cDecoder;
class cFileSource;

// ----------------------------------------------------------------

class cSong : public cListObject {
private:
  char *name, *fullname;
  cFileSource *source;
  bool fromDOS, decoderFailed;
  cDecoder *decoder;
  cMutex decLock;
  //
  void Set(const char *Name);
  void Clear(void);
  char *Convert2Unix(void);
  char *Convert2Dos(void);
public:
  cSong(const char *Name, cFileSource *Source);
  ~cSong();
  bool Parse(char *s);
  bool Save(FILE *f);
  void Convert(void);
  cSongInfo *Info(bool get=true);
  cDecoder *Decoder(void);
  const char *Name(void) { return name; }
  };

// ----------------------------------------------------------------

class cPlayList : public cList<cSong>, public cListObject {
private:
  bool isWinAmp;
  char *extbuffer;
  //
  void Set(const char *Name);
  const char *AddExt(const char *Name, const char *Ext);
protected:
  char *name, *basename, *fullname;
  cFileSource *source;
public:
  cPlayList(const char *Name, cFileSource *Source);
  ~cPlayList();
  virtual bool Load(void);
  virtual bool Save(void);
//
  bool Rename(const char *newName);
  bool Delete(void);
  bool Create(const char *newName);
  bool Exists(void);
  bool TestName(const char *newName);
  const char *Name(void) { return name; }
  const char *BaseName(void) { return basename; }
  bool IsWinAmp(void) { return isWinAmp; }
  };

// ----------------------------------------------------------------

class cInstantPlayList : public cScanDir, public cPlayList {
private:
  cDirItem item;
protected:
  virtual void DoItem(cFileSource *src, const char *subdir, const char *name);
public:
  cInstantPlayList(cDirItem *Item);
  virtual bool Load(void);
  virtual bool Save(void) { return false; }
  };

// ----------------------------------------------------------------

class cPlayLists : public cScanDir, public cList<cPlayList> {
protected:
  virtual void DoItem(cFileSource *src, const char *subdir, const char *name);
public:
  bool Load(cFileSource *Source);
  };

#endif //___DATA_MP3_H
